<?php
/**
 * RegisterAssetsComponent.php
 *
 * This file register all assets.
 * 
 * USAGE:
 * 
 * Place AssetsRegistryComponent.php into components
 * 
 * In layout <?php app()->AssetsRegistry; ?>
 * 
 * In config/main.php
 * 
 * 'components' => array(
 *				'AssetsRegistry' => array(
 *					'class' => 'AssetsRegistryComponent'
 *					'config' =>'application.config.assetsregistry' <- path to your config file (default config.assetsregistry)
 *				),
 *
 *				
 * @author: Litvinov Alexander <sanderlimail@gmail.com>
 * Date: 31/07/13
 * Time: 23:47 PM
 */
class AssetsRegistryComponent extends CApplicationComponent{
	
	private  $_registerAssetsConfig;
	
	/**
	 * path to config file
	 * @var string
	 */
	public $config = 'application.config.assetsregistry';

	/**
	 * Initializes the component.
	 */
	public function init(){ 
		parent::init(); 
		$this->_registerAssetsConfig = require_once(Yii::getPathOfAlias($this->config).'.php');
		$this->_registerAll(); 
	}

   /**
	* Registers the Layout Js.
	*/
	private function _registerLayoutJs(){ 
		if(isset($this->_registerAssetsConfig['layout']['js'])):
		$configs = $this->_registerAssetsConfig['layout']['js'];  
		foreach ($configs as $config){
			$url = isset($config['url']) ? $config['url'] : 'js';
			$pos = isset($config['pos']) ? $config['pos'] : CClientScript::POS_HEAD; 
			regJsFile($config['files'], $url, $pos); 
		}
		endif;
	}

   /**
	* Registers the Route Js.
	*/
	private function _registerRouteJs(){
		if(isset($this->_registerAssetsConfig[app()->controller->route])):
			$configs = $this->_registerAssetsConfig[app()->controller->route]['js']; 
			foreach ($configs as $config){
				$url = isset($config['url']) ? $config['url'] : 'js';
				$pos = isset($config['pos']) ? $config['pos'] : CClientScript::POS_HEAD;
				regJsFile($config['files'], $url, $pos); 
			}
		endif;
	}
	
	/**
	* Registers the All Js.
	*/
	private function _registerAllJs(){
		$this->_registerLayoutJs(); 
		$this->_registerRouteJs();
	}

   /**
	* Registers the Layout CSS.
	*/
	private function _registerLayoutCss(){
		if(isset($this->_registerAssetsConfig['layout']['css'])):
		$configs = $this->_registerAssetsConfig['layout']['css']; 
		foreach ($configs as $config){  
			$url = isset($config['url']) ? $config['url'] : 'css';
			$addBaseUrl = isset($config['addBaseUrl']) ? $config['addBaseUrl'] : true;
			regCssFile($config['files'], $url, $addBaseUrl);
		}
		endif;
	}
	
   /**
	* Registers the Route CSS.
	*/
	private function _registerRouteCss(){
		if(isset($this->_registerAssetsConfig[app()->controller->route]['css'])):
		$configs = $this->_registerAssetsConfig[app()->controller->route]['css'];
		foreach ($configs as $config){
			$url = isset($config['url']) ? $config['url'] : 'js';
			$addBaseUrl = isset($config['addBaseUrl']) ? $config['addBaseUrl'] : CClientScript::POS_HEAD;
			regCssFile($config['files'], $url, $addBaseUrl);
		}
		endif;
	}
   
   /**
	* Registers the All CSS.
	*/
	private function _registerAllCss(){
		$this->_registerLayoutCss();
		$this->_registerRouteCss();
	}
	
	/**
	* Registers the All files.
	*/
	private function _registerAll(){
		$this->_registerAllCss();
		$this->_registerAllJs();
	}
}